@@ -16,7 +16,7 @@ import argparse
 from quantrocket.cli.utils.parse import dict_str, list_or_int_or_float_or_str
 
 def add_subparser(subparsers):
-    _parser = subparsers.add_parser("moonshot", description="QuantRocket Moonshot CLI", help="Backtest and trade with Moonshot")
+    _parser = subparsers.add_parser("moonshot", description="QuantRocket Moonshot CLI", help="Backtest and trade Moonshot strategies")
     _subparsers = _parser.add_subparsers(title="subcommands", dest="subcommand")
     _subparsers.required = True
 
@@ -93,6 +93,12 @@ Run a backtest in 1-year segments to reduce memory usage:
         metavar="PARAM:VALUE",
         help="one or more strategy params to set on the fly before backtesting "
         "(pass as 'param:value')")
+    backtest_options.add_argument(
+        "--no-cache",
+        action="store_true",
+        help="don't use cached files even if available. Using cached files speeds "
+        "up backtests but may be undesirable if underlying data has changed. "
+        "See http://qrok.it/h/mcache to learn more about caching in Moonshot.")
     outputs = parser.add_argument_group("output options")
     outputs.add_argument(
         "-d", "--details",
@@ -208,6 +214,12 @@ Run a parameter scan in 1-year segments to reduce memory usage:
         metavar="PARAM:VALUE",
         help="one or more strategy params to set on the fly before backtesting "
         "(pass as 'param:value')")
+    backtest_options.add_argument(
+        "--no-cache",
+        action="store_true",
+        help="don't use cached files even if available. Using cached files speeds "
+        "up backtests but may be undesirable if underlying data has changed. "
+        "See http://qrok.it/h/mcache to learn more about caching in Moonshot.")
     outputs = parser.add_argument_group("output options")
     outputs.add_argument(
         "--pdf",
@@ -223,7 +235,7 @@ Run a parameter scan in 1-year segments to reduce memory usage:
     parser.set_defaults(func="quantrocket.moonshot._cli_scan_parameters")
 
     examples = """
-Run a walk-forward backtest of a machine learning strategy.
+Run a walk-forward optimization of a machine learning strategy.
 
 The date range will be split into segments of `--train` size. For each
 segment, the model will be trained with the data, then the trained model will
@@ -234,8 +246,8 @@ scikit-learn models/pipelines and Keras models. To customize model, instantiate
 the model locally, serialize it to disk, and pass the filename of the serialized
 model as `--model`.
 
-Supports expanding walk-forward backtests (the default), which use an anchored start date
-for model training, or rolling walk-forward backtests (by specifying `--rolling-train`),
+Supports expanding walk-forward optimizations (the default), which use an anchored start date
+for model training, or rolling walk-forward optimizations (by specifying `--rolling-train`),
 which use a rolling or non-anchored start date for model training.
 
 Returns a backtest results CSV and a dump of the machine learning model
@@ -243,13 +255,13 @@ as of the end of the analysis.
 
 Examples:
 
-Run a walk-forward backtest using the default model and retrain the model annually,
+Run a walk-forward optimization using the default model and retrain the model annually,
 writing the backtest results and trained model to demo_ml_results.csv and
 demo_ml_trained_model.joblib, respectively:
 
     quantrocket moonshot ml-walkforward demo-ml -s 2007-01-01 -e 2018-12-31 --train A -o demo_ml*
 
-Run a walk-forward backtest using a custom model (serialized with joblib), retrain the
+Run a walk-forward optimization using a custom model (serialized with joblib), retrain the
 model annually, don't perform backtesting until after 5 years of initial training,
 and further split the training and backtesting into quarterly segments to reduce
 memory usage:
@@ -258,7 +270,7 @@ memory usage:
     """
     parser = _subparsers.add_parser(
         "ml-walkforward",
-        help="run a walk-forward backtest of a machine learning strategy",
+        help="run a walk-forward optimization of a machine learning strategy",
         epilog=examples,
         formatter_class=argparse.RawDescriptionHelpFormatter)
     parser.add_argument(
@@ -271,7 +283,7 @@ memory usage:
         metavar="YYYY-MM-DD",
         required=True,
         help="the analysis start date (note that model training will start on this date "
-        "but backtest will not start until after the initial training period)")
+        "but backtesting will not start until after the initial training period)")
     walkforward_options.add_argument(
         "-e", "--end-date",
         metavar="YYYY-MM-DD",
@@ -305,7 +317,7 @@ memory usage:
         action="store_true",
         help="force the model to be trained non-incrementally (i.e. load entire training "
         "data set into memory) even if it supports incremental learning. Required "
-        "in order to perform a rolling (as opposed to expanding) walk-forward backtest "
+        "in order to perform a rolling (as opposed to expanding) walk-forward optimization "
         "with a model that supports incremental learning.")
     backtest_options = parser.add_argument_group("backtest options")
     backtest_options.add_argument(
@@ -335,6 +347,12 @@ memory usage:
         metavar="PARAM:VALUE",
         help="one or more strategy params to set on the fly before backtesting "
         "(pass as 'param:value')")
+    backtest_options.add_argument(
+        "--no-cache",
+        action="store_true",
+        help="don't use cached files even if available. Using cached files speeds "
+        "up backtests but may be undesirable if underlying data has changed. "
+        "See http://qrok.it/h/mcache to learn more about caching in Moonshot.")
     outputs = parser.add_argument_group("output options")
     outputs.add_argument(
         "-d", "--details",
